ShowTextArray

Struct ShowTextArray 

pub struct ShowTextArray(/* private fields */);
TJ operator.

Show zero or more text strings, allowing individual glyph positioning. Each element of the array is either a string or a number:

  • in the case of a string, the operator shows the text;
  • in the case of a number, the operator adjust the text position by that amount (i.e. translate the text matrix). Expressed in thousandths of text space units. That amount is subtracted from the current “selected coordinate”, depending on the writing mode.
[(5)-6(1)-6(,)-2( )-2(A)] TJ