PageTreeNode

Struct PageTreeNode 

pub struct PageTreeNode { /* private fields */ }
Intermediate page nodes, and the type of the Pages element in the document’s Catalog.

From the PDF specification:

The simplest structure can consist of a single page tree node that references all of the document’s page objects directly. However, to optimise application performance, a PDF writer can construct trees of a particular form, known as balanced trees.

In Livre, the page tree is immediately transformed into a vector of Pages for simplicity. Hence this type, along with other low-level types, are made public for reference only.

Implementations

Source

impl PageTreeNode

pub fn list_pages<B>(&self, builder: &B) -> PResult<Vec<Page>>
where B: Builder,