Livre (pronounced [livʁ], the French word for book) aims to provide a set of type-safe tools to read PDF content.
Modules
- content
- Utilities for parsing and manipulating page content.
- extraction
- Definition of the extraction logic, organised around one main trait:
Extract- and its implementation for primitive types. - follow_
refs - A set of primitives that extend the
extractionmodule to follow references and extract indirect objects in order to “build” more complex PDF structures. - structure
- Types that describe the structure of a PDF document and their extraction strategies.