pub struct ShowTextArray(/* private fields */);Expand description
TJ operator.
Show zero or more text strings, allowing individual glyph positioning. Each element of the array is either a string or a number:
- in the case of a string, the operator shows the text;
- in the case of a number, the operator adjust the text position by that amount (i.e. translate the text matrix). Expressed in thousandths of text space units. That amount is subtracted from the current “selected coordinate”, depending on the writing mode.
[(5)-6(1)-6(,)-2( )-2(A)] TJTrait Implementations
Sourceimpl Clone for ShowTextArray
impl Clone for ShowTextArray
Sourcefn clone(&self) -> ShowTextArray
fn clone(&self) -> ShowTextArray
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ShowTextArray
impl Debug for ShowTextArray
Sourceimpl Display for ShowTextArray
impl Display for ShowTextArray
Sourceimpl<'de> Extract<'de> for ShowTextArray
impl<'de> Extract<'de> for ShowTextArray
Sourceimpl From<ShowTextArray> for TextOperator
impl From<ShowTextArray> for TextOperator
Sourcefn from(op: ShowTextArray) -> Self
fn from(op: ShowTextArray) -> Self
Converts to this type from the input type.
Sourceimpl From<ShowTextArray> for TextShowingOperator
impl From<ShowTextArray> for TextShowingOperator
Sourcefn from(v: ShowTextArray) -> TextShowingOperator
fn from(v: ShowTextArray) -> TextShowingOperator
Converts to this type from the input type.
Sourceimpl PartialEq for ShowTextArray
impl PartialEq for ShowTextArray
Sourcefn eq(&self, other: &ShowTextArray) -> bool
fn eq(&self, other: &ShowTextArray) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TextOperation for ShowTextArray
impl TextOperation for ShowTextArray
Sourceimpl TryInto<ShowTextArray> for TextShowingOperator
impl TryInto<ShowTextArray> for TextShowingOperator
impl StructuralPartialEq for ShowTextArray